@@ -32,7 +32,7 @@ use Getopt::Euclid qw( :vars<opt_> );
 use List::MoreUtils qw{firstidx} ;
 use Data::Dumper;
 
-use version ; our $VERSION = qv('1.3.2');
+use version ; our $VERSION = qv('1.4.0');
 
 our @opt_infile;
 our @opt_outfile;
@@ -47,6 +47,8 @@ our $opt_prefile;
 our $opt_postfile;
 our $opt_cleanupfile;
 our $opt_namespace;
+our $opt_nogeneratePassedResults;
+
 
 my $version             = $opt_version ;
 
@@ -65,7 +67,7 @@ my @resultSets              = () ;
    @resultSets              = @opt_resultSets if @opt_resultSets ;
 my $generateAllResultSets   = ! ( scalar @resultSets ) ;
 my $generateScalarChecks    = $opt_scalarValues ;
-
+my $generatePassedResults   = $opt_nogeneratePassedResults ;
 
 my %Parsers = () ;
 my %ValidParserMakeArgs = ( vb  => 'NET::VB'
@@ -179,169 +181,198 @@ for ( my $i=0; $i <= $#opt_infile; $i++ ) {  ## Process SQL scripts:::
     $TestSQL = $dbh->quote($TestSQL) ;
     $TestSQL = 'exec sp_executesql N' . $TestSQL ;
 
-    if ( $initSQL ) {
-### Run initialisation script
-        my $p_sth = $priv_dbh->prepare($initSQL,{odbc_exec_direct => 1});
-        $p_sth->execute();
-    }
-    if ( $PreTestSQL ) {
-### Run pre-test script
-        my $p_sth = $priv_dbh->prepare($PreTestSQL,{odbc_exec_direct => 1});
-        $p_sth->execute();
-    }
+	
+	my @testConditions = () ;
+	my $conditionNamePrefix             = "${outfname}_Res_" ;
+	
+	Readonly::Scalar  my $testConditionTypeRC => 'RowCount' ;
+	Readonly::Scalar  my $testConditionTypeSV => 'ScalarValue' ;
+	
+	if ( $generatePassedResults ) {
 
-### Run test script once
-
-    my @run1_res ;
-    my @res_col ;
-    my @res_type ;
-    my $sth = $dbh->prepare($TestSQL,{odbc_exec_direct => 1});
-
-    try {
-        $sth->execute;
-    } catch {
-         #warn "caught error: $_\n";
-         warn "File :- $infile\n";
-         #warn "TRYING :- \n$TestSQL";
-    };
-
-
-    do {
-        push @res_type, $sth->{TYPE} ;
-        push @res_col,  $sth->{NAME} ;
-
-        if ( $gen_types ) {
-            {
-            my @names   = map { scalar $dbh_typeinfo->type_info($_)->{TYPE_NAME} }   @{ $sth->{TYPE} } ;
-            my @colSize = map { scalar $dbh_typeinfo->type_info($_)->{COLUMN_SIZE} } @{ $sth->{TYPE} } ;
-
-            my @types = List::MoreUtils::pairwise { $a =~ m{char}ism ? "$a($b)" : "$a" }  @names, @colSize ;
-            my @spec  = List::MoreUtils::pairwise { "$a\t\t\t$b" }  @{$sth->{NAME}}, @types ;
-
-            do { local $"= "\n,\t" ;
-                 say {*STDERR} "ResultSet(\n\t@{spec}\n)";
-               }
-            }
-        }
-
-        push @run1_res, $sth->fetchall_arrayref() ;
-
-    } while ($sth->{odbc_more_results}) ;
-
-
-    foreach my $row (@res_col) {
-        for ( my $i = 0; $i < scalar (@$row) ; $i++ ) {
-            my $y=$i+1;
-            $$row[$i]  = "Col_${y}" if $$row[$i] eq q{} ;
-        }
-    }
-
-### Run test script twice
-
-    my @run2_res ;
-    $sth = $dbh->prepare($TestSQL,{odbc_exec_direct => 1});
-    $sth->execute;
-    do {
-        push @run2_res, $sth->fetchall_arrayref() ;
-
-    } while ($sth->{odbc_more_results}) ;
-
-    my @testConditions = () ;
-
-    my $G_ln = 0 ;
-
-### Build conditions
-
-    my $conditionNamePrefix             = "${outfname}_Res_" ;
-
-    Readonly::Scalar  my $testConditionTypeRC => 'RowCount' ;
-    Readonly::Scalar  my $testConditionTypeSV => 'ScalarValue' ;
-
-    for ( my $ra_arr = 0; $ra_arr < scalar (@res_col) ; $ra_arr++ ) {
-
-        unless ( $generateAllResultSets ) {
-            next unless any { $_ == ($ra_arr+1) } @resultSets ;
-        }
-    #warn Dumper @resultSets ;
-    #warn "!!!!\n";
-    #warn Dumper $ra_arr ;
-
-        my $testConditionRC = VSGDR::UnitTest::TestSet::Test::TestCondition->make(
-                    { TESTCONDITIONTYPE         => $testConditionTypeRC
-                    , CONDITIONTESTACTIONNAME   => ${TestActionName}
-                    , CONDITIONNAME             => ${conditionNamePrefix} . ($ra_arr+1) . "_RowCount"
-                    , CONDITIONENABLED          => 'True'
-                    , CONDITIONROWCOUNT         => scalar(@{$run1_res[$ra_arr]})
-                    , CONDITIONRESULTSET        => $ra_arr+1
-                    } ) ;
-        push @testConditions, $testConditionRC ;
-
-        my $single_row_output = ( scalar(@{$run1_res[$ra_arr]}) == 1
-                                                           ? 1
-                                                           : 0 );
-
-        if ( $generateScalarChecks) {
-            for ( my $ra_row = 0; $ra_row < scalar ( @{$run1_res[$ra_arr]} ) ; $ra_row++ ) {
-
-                for ( my $ra_col = 0; $ra_col < scalar ( @{$res_col[$ra_arr]} ) ; $ra_col++ ) {
-
-                    my $run1_dataValue = VSGDR::SQLServer::DataType->make( $res_type[$ra_arr][$ra_col]
-                                                                              , $run1_res[$ra_arr][$ra_row][$ra_col]
-                                                                              ) ;
-
-                    my $run2_dataValue = VSGDR::SQLServer::DataType->make( $res_type[$ra_arr][$ra_col]
-                                                                              , $run2_res[$ra_arr][$ra_row][$ra_col]
-                                                                              ) ;
-
-                    # check the values are stable from run to run before generating test condition.
-                    if ( ( ( ! defined $run1_dataValue->value() ) and (! defined $run2_dataValue->value() ) ) or
-                         ( (   defined $run1_dataValue->value()   and    defined $run2_dataValue->value() )
-                                    and  $run1_dataValue eq $run2_dataValue
-                         )
-                       ) {
-                        my $testConditionSV = VSGDR::UnitTest::TestSet::Test::TestCondition->make(
-                                    { TESTCONDITIONTYPE         => $testConditionTypeSV
-                                    , CONDITIONTESTACTIONNAME   => ${TestActionName}
-                                    , CONDITIONNAME             => ( $single_row_output == 0
-                                                                        ? ${conditionNamePrefix} . ($ra_arr+1) . '_Row_' . ($ra_row+1) . '_' . $res_col[$ra_arr][$ra_col]
-                                                                        : ${conditionNamePrefix} . ($ra_arr+1) . '_' . $res_col[$ra_arr][$ra_col]
-                                                                   )
-                                    , CONDITIONENABLED          => 'True'
-                                    , CONDITIONEXPECTEDVALUE    => ( defined $run1_dataValue->getValue()
-                                                                        ? q{"} .    # " kill highlighting
-                                                                        $run1_dataValue->quoteValue($run1_dataValue->getValue()) 
-                                                                        . q{"}      # " kill highlighting
-                                                                        : 'null'
-                                                                   )
-                                    , CONDITIONNULLEXPECTED     => defined $run1_res[$ra_arr][$ra_row][$ra_col] ? 'False' : 'True'
-                                    , CONDITIONRESULTSET        => $ra_arr+1
-                                    , CONDITIONROWNUMBER        => $ra_row+1
-                                    , CONDITIONCOLUMNNUMBER     => $ra_col+1
-                                    } ) ;
-
-                        push @testConditions, $testConditionSV ;
-                    }
-                    else {
-                        say {*STDERR} "Skipping mutating values for resultset\[${ra_arr}\], row\[${ra_row}\], column\[${ra_col}\] .." ;
-                    }
-                }
-            }
-        }
-    }
-
-
-    if ( $PostTestSQL ) {
-### Run post-test script
-        my $p_sth = $priv_dbh->prepare($PostTestSQL,{odbc_exec_direct => 1});
-        $p_sth->execute();
-    }
-
-    if ( $cleardownSQL ) {
-### Run cleardown script
-        my $p_sth = $priv_dbh->prepare($cleardownSQL,{odbc_exec_direct => 1});
-        $p_sth->execute();
-    }
+		my $testConditionRC = VSGDR::UnitTest::TestSet::Test::TestCondition->make(
+					{ TESTCONDITIONTYPE         => $testConditionTypeRC
+					, CONDITIONTESTACTIONNAME   => ${TestActionName}
+					, CONDITIONNAME             => ${conditionNamePrefix} . "1_RowCount"
+					, CONDITIONENABLED          => 'True'
+					, CONDITIONROWCOUNT         => 1
+					, CONDITIONRESULTSET        => 1
+					} ) ;
+		push @testConditions, $testConditionRC ;
+	
+		my $testConditionSV = VSGDR::UnitTest::TestSet::Test::TestCondition->make(
+					{ TESTCONDITIONTYPE         => $testConditionTypeSV
+					, CONDITIONTESTACTIONNAME   => ${TestActionName}
+					, CONDITIONNAME             => ${conditionNamePrefix} . '1_Col_1'
+					, CONDITIONENABLED          => 'True'
+					, CONDITIONEXPECTEDVALUE    => 'Passed'
+					, CONDITIONNULLEXPECTED     => 'False'
+					, CONDITIONRESULTSET        => 1
+					, CONDITIONROWNUMBER        => 1
+					, CONDITIONCOLUMNNUMBER     => 1
+					} ) ;
+	
+		push @testConditions, $testConditionSV ;
 
+	}
+	else { 
+		if ( $initSQL ) {
+### 	Run initialisation script
+			my $p_sth = $priv_dbh->prepare($initSQL,{odbc_exec_direct => 1});
+			$p_sth->execute();
+		}
+		if ( $PreTestSQL ) {
+### 	Run pre-test script
+			my $p_sth = $priv_dbh->prepare($PreTestSQL,{odbc_exec_direct => 1});
+			$p_sth->execute();
+		}
+	
+### 	Run test script once
+	
+		my @run1_res ;
+		my @res_col ;
+		my @res_type ;
+		my $sth = $dbh->prepare($TestSQL,{odbc_exec_direct => 1});
+	
+		try {
+			$sth->execute;
+		} catch {
+			#warn "caught error: $_\n";
+			warn "File :- $infile\n";
+			#warn "TRYING :- \n$TestSQL";
+		};
+	
+	
+		do {
+			push @res_type, $sth->{TYPE} ;
+			push @res_col,  $sth->{NAME} ;
+	
+			if ( $gen_types ) {
+				{
+				my @names   = map { scalar $dbh_typeinfo->type_info($_)->{TYPE_NAME} }   @{ $sth->{TYPE} } ;
+				my @colSize = map { scalar $dbh_typeinfo->type_info($_)->{COLUMN_SIZE} } @{ $sth->{TYPE} } ;
+	
+				my @types = List::MoreUtils::pairwise { $a =~ m{char}ism ? "$a($b)" : "$a" }  @names, @colSize ;
+				my @spec  = List::MoreUtils::pairwise { "$a\t\t\t$b" }  @{$sth->{NAME}}, @types ;
+	
+				do { local $"= "\n,\t" ;
+					say {*STDERR} "ResultSet(\n\t@{spec}\n)";
+				}
+				}
+			}
+	
+			push @run1_res, $sth->fetchall_arrayref() ;
+	
+		} while ($sth->{odbc_more_results}) ;
+	
+	
+		foreach my $row (@res_col) {
+			for ( my $i = 0; $i < scalar (@$row) ; $i++ ) {
+				my $y=$i+1;
+				$$row[$i]  = "Col_${y}" if $$row[$i] eq q{} ;
+			}
+		}
+	
+### 	Run test script twice
+	
+		my @run2_res ;
+		$sth = $dbh->prepare($TestSQL,{odbc_exec_direct => 1});
+		$sth->execute;
+		do {
+			push @run2_res, $sth->fetchall_arrayref() ;
+	
+		} while ($sth->{odbc_more_results}) ;
+	
+		my $G_ln = 0 ;
+	
+### 	Build conditions
+	
+		for ( my $ra_arr = 0; $ra_arr < scalar (@res_col) ; $ra_arr++ ) {
+	
+			unless ( $generateAllResultSets ) {
+				next unless any { $_ == ($ra_arr+1) } @resultSets ;
+			}
+		#warn Dumper @resultSets ;
+		#warn "!!!!\n";
+		#warn Dumper $ra_arr ;
+	
+			my $testConditionRC = VSGDR::UnitTest::TestSet::Test::TestCondition->make(
+						{ TESTCONDITIONTYPE         => $testConditionTypeRC
+						, CONDITIONTESTACTIONNAME   => ${TestActionName}
+						, CONDITIONNAME             => ${conditionNamePrefix} . ($ra_arr+1) . "_RowCount"
+						, CONDITIONENABLED          => 'True'
+						, CONDITIONROWCOUNT         => scalar(@{$run1_res[$ra_arr]})
+						, CONDITIONRESULTSET        => $ra_arr+1
+						} ) ;
+			push @testConditions, $testConditionRC ;
+	
+			my $single_row_output = ( scalar(@{$run1_res[$ra_arr]}) == 1
+															? 1
+															: 0 );
+	
+	
+			if ( $generateScalarChecks) {
+				for ( my $ra_row = 0; $ra_row < scalar ( @{$run1_res[$ra_arr]} ) ; $ra_row++ ) {
+	
+					for ( my $ra_col = 0; $ra_col < scalar ( @{$res_col[$ra_arr]} ) ; $ra_col++ ) {
+	
+						my $run1_dataValue = VSGDR::SQLServer::DataType->make( $res_type[$ra_arr][$ra_col]
+																				, $run1_res[$ra_arr][$ra_row][$ra_col]
+																				) ;
+	
+						my $run2_dataValue = VSGDR::SQLServer::DataType->make( $res_type[$ra_arr][$ra_col]
+																				, $run2_res[$ra_arr][$ra_row][$ra_col]
+																				) ;
+	
+						# check the values are stable from run to run before generating test condition.
+						if ( ( ( ! defined $run1_dataValue->value() ) and (! defined $run2_dataValue->value() ) ) or
+							( (   defined $run1_dataValue->value()   and    defined $run2_dataValue->value() )
+										and  $run1_dataValue eq $run2_dataValue
+							)
+						) {
+							my $testConditionSV = VSGDR::UnitTest::TestSet::Test::TestCondition->make(
+										{ TESTCONDITIONTYPE         => $testConditionTypeSV
+										, CONDITIONTESTACTIONNAME   => ${TestActionName}
+										, CONDITIONNAME             => ( $single_row_output == 0
+																			? ${conditionNamePrefix} . ($ra_arr+1) . '_Row_' . ($ra_row+1) . '_' . $res_col[$ra_arr][$ra_col]
+																			: ${conditionNamePrefix} . ($ra_arr+1) . '_' . $res_col[$ra_arr][$ra_col]
+																	)
+										, CONDITIONENABLED          => 'True'
+										, CONDITIONEXPECTEDVALUE    => ( defined $run1_dataValue->getValue()
+																			? q{"} .    # " kill highlighting
+																			$run1_dataValue->quoteValue($run1_dataValue->getValue()) 
+																			. q{"}      # " kill highlighting
+																			: 'null'
+																	)
+										, CONDITIONNULLEXPECTED     => defined $run1_res[$ra_arr][$ra_row][$ra_col] ? 'False' : 'True'
+										, CONDITIONRESULTSET        => $ra_arr+1
+										, CONDITIONROWNUMBER        => $ra_row+1
+										, CONDITIONCOLUMNNUMBER     => $ra_col+1
+										} ) ;
+	
+							push @testConditions, $testConditionSV ;
+						}
+						else {
+							say {*STDERR} "Skipping mutating values for resultset\[${ra_arr}\], row\[${ra_row}\], column\[${ra_col}\] .." ;
+						}
+					}
+				}
+			}
+		}
+	
+	
+		if ( $PostTestSQL ) {
+### 	Run post-test script
+			my $p_sth = $priv_dbh->prepare($PostTestSQL,{odbc_exec_direct => 1});
+			$p_sth->execute();
+		}
+	
+		if ( $cleardownSQL ) {
+### 	Run cleardown script
+			my $p_sth = $priv_dbh->prepare($cleardownSQL,{odbc_exec_direct => 1});
+			$p_sth->execute();
+		}
+	}
 
 ### Build GDR files
 
@@ -410,7 +441,7 @@ Test is run tw2ce to generate tests only for stable values. (Dates are still a p
 
 =head1 VERSION
 
-1.3.1
+1.4.0
 
 =head1 USAGE
 
@@ -511,6 +542,15 @@ Specify namespace for test class
 
 
 
+=item  --[no]generatePassedResults
+
+[Don't] generate 'Passed' scalar value result ie don't run the tests
+
+=for Euclid:
+    false: --generatePassedResults
+
+
+
 
 =item  --[no]scalarValues
 
